==> glib-web-0.11.8.tgz: package/utils/url.js <==
import TypeUtils from "./type";

export default class {
  static htmlUrl(originalUrl) {
    if (TypeUtils.isString(originalUrl)) {
      let url;
      if (originalUrl.indexOf("?") > -1) {
        url = originalUrl.replace(/.json\?/, "?");
      } else {
        url = originalUrl.replace(/.json$/, "");
      }
      // As much as possible, try retaining the front fragment by matching the back, because
      // the front could be either a `?` or `&`
      url = url.replace(/format=json\&/, "");
      // If no match, then we replace the front fragment
      url = url.replace(/[\&\?]format=json/, "");
      return url;
    }
    return "";
  }

  static jsonUrl(originalUrl) {
    if (typeof originalUrl === "string") {
      let url = originalUrl;
      if (originalUrl.indexOf("?") > -1) {
        if (
          originalUrl.indexOf(".json?") == -1 &&
          originalUrl.search(/[\&\?]format=json/) == -1
        ) {
          url = originalUrl + "&format=json";
        }
      } else {
        if (!originalUrl.endsWith(".json")) {
          url = originalUrl + "?format=json";
        }
      }
      return url;
    }
    return "";
  }

  static toFormData(params) {
    const formData = new FormData();
    for (const key in params) {
      formData.append(key, params[key]);
    }
    return formData;
  }

  static toMap(formData) {
    return this._extractUrlParams(new URLSearchParams(formData).toString());
  }

  static appendParams(url, params) {
    if (params instanceof FormData) {
      const queryString = new URLSearchParams(params).toString();
      if (queryString.length <= 0) {
        return url;
      }
      if (url.contains("?")) {
        return url + `&${queryString}`;
      } else {
        return url + `?${queryString}`;
      }
    } else {
      return this.appendParams(url, this.toFormData(params));
      // throw "Invalid params"
    }
  }

  // static asQueryString(obj) {
  //   if (!TypeUtils.isObject(obj)) {
  //     return ""
  //   }
  //
  //   var str = [];
  //   for (var p in obj) {
  //     if (obj.hasOwnProperty(p)) {
  //       str.push(encodeURIComponent(p) + "=" + encodeURIComponent(obj[p]))
  //     }
  //   }
  //   return str.join("&")
  // }

  static extractFormActionData(originalUrl, local) {
    if (typeof originalUrl === "string") {
      const substitute = local ? "" : ".json";
      let url;
      if (originalUrl.indexOf("?") > -1) {
        url = originalUrl.replace(/.json\?.*/, substitute);
      } else {
        url = originalUrl.replace(/.json$/, substitute);
      }
      return { url: url, params: this._extractUrlParams(originalUrl) };
    }
    return {};
  }

  // // https://gist.github.com/pirate/9298155edda679510723
  static _extractUrlParams(search) {
    const hashes = search.slice(search.indexOf("?") + 1).split("&");
    return hashes.reduce((params, hash) => {
      const split = hash.indexOf("=");

      if (split < 0) {
        return Object.assign(params, {
          [hash]: null
        });
      }

      const name = hash.slice(0, split);
      const val = hash.slice(split + 1);
      const key = decodeURIComponent(name);
      if (key.endsWith("[]")) {
        if (params[key]) {
          params[key].push(val);
          return params;
        } else {
          return Object.assign(params, {
            [key]: [this._decodeParamValue(val)]
          });
        }
      } else {
        return Object.assign(params, {
          [key]: this._decodeParamValue(val)
        });
      }
    }, {});
  }

  static _decodeParamValue(value) {
    // See https://stackoverflow.com/questions/18717557/remove-plus-sign-in-url-query-string/24417399
    const encodedSpaces = value.replace(/\+/g, "%20");
    return decodeURIComponent(encodedSpaces);
  }
}

==> glib-web-2.6.3.tgz: package/utils/url.js <==
import TypeUtils from "./type";

export default class {
  static htmlUrl(originalUrl) {
    if (TypeUtils.isString(originalUrl)) {
      let url;
      if (originalUrl.indexOf("?") > -1) {
        url = originalUrl.replace(/.json\?/, "?");
      } else {
        url = originalUrl.replace(/.json$/, "");
      }
      // As much as possible, try retaining the front fragment by matching the back, because
      // the front could be either a `?` or `&`
      url = url.replace(/format=json\&/, "");
      // If no match, then we replace the front fragment
      url = url.replace(/[\&\?]format=json/, "");
      return url;
    }
    return "";
  }

  static jsonUrl(originalUrl) {
    if (typeof originalUrl === "string") {
      const fragments = originalUrl.split("#");
      let url = fragments[0];
      const anchor = fragments[1];
      if (url.indexOf("?") > -1) {
        if (
          url.indexOf(".json?") == -1 &&
          url.search(/[\&\?]format=json/) == -1
        ) {
          url = url + "&format=json";
        }
      } else {
        if (!url.endsWith(".json")) {
          url = url + "?format=json";
        }
      }
      return anchor ? `${url}#${anchor}` : url;
    }
    return "";
  }

  static toFormData(params) {
    const formData = new FormData();
    for (const key in params) {
      formData.append(key, params[key]);
    }
    return formData;
  }

  static toMap(formData) {
    return this._extractUrlParams(new URLSearchParams(formData).toString());
  }

  static appendParams(url, params) {
    if (params instanceof FormData) {
      const queryString = new URLSearchParams(params).toString();
      if (queryString.length <= 0) {
        return url;
      }
      if (url.contains("?")) {
        return url + `&${queryString}`;
      } else {
        return url + `?${queryString}`;
      }
    } else {
      return this.appendParams(url, this.toFormData(params));
      // throw "Invalid params"
    }
  }

  // static asQueryString(obj) {
  //   if (!TypeUtils.isObject(obj)) {
  //     return ""
  //   }
  //
  //   var str = [];
  //   for (var p in obj) {
  //     if (obj.hasOwnProperty(p)) {
  //       str.push(encodeURIComponent(p) + "=" + encodeURIComponent(obj[p]))
  //     }
  //   }
  //   return str.join("&")
  // }

  static extractFormActionData(originalUrl, local) {
    if (typeof originalUrl === "string") {
      const substitute = local ? "" : ".json";
      let url;
      if (originalUrl.indexOf("?") > -1) {
        url = originalUrl.replace(/.json\?.*/, substitute);
      } else {
        url = originalUrl.replace(/.json$/, substitute);
      }
      return { url: url, params: this._extractUrlParams(originalUrl) };
    }
    return {};
  }

  // // https://gist.github.com/pirate/9298155edda679510723
  static _extractUrlParams(search) {
    const hashes = search.slice(search.indexOf("?") + 1).split("&");
    return hashes.reduce((params, hash) => {
      const split = hash.indexOf("=");

      if (split < 0) {
        return Object.assign(params, {
          [hash]: null
        });
      }

      const name = hash.slice(0, split);
      const val = hash.slice(split + 1);
      const key = decodeURIComponent(name);
      if (key.endsWith("[]")) {
        if (params[key]) {
          params[key].push(val);
          return params;
        } else {
          return Object.assign(params, {
            [key]: [this._decodeParamValue(val)]
          });
        }
      } else {
        return Object.assign(params, {
          [key]: this._decodeParamValue(val)
        });
      }
    }, {});
  }

  static _decodeParamValue(value) {
    // See https://stackoverflow.com/questions/18717557/remove-plus-sign-in-url-query-string/24417399
    const encodedSpaces = value.replace(/\+/g, "%20");
    return decodeURIComponent(encodedSpaces);
  }
}
